import * as tslib_1 from "tslib";
import { Component, Input, Output, EventEmitter, ChangeDetectionStrategy, ViewChild, ElementRef } from '@angular/core';
import * as common from 'schema-based-json-editor';
import JSON5 from 'json5';
import { anyEditorTemplateHtml } from './variables';
var AnyEditorComponent = /** @class */ (function () {
    function AnyEditorComponent() {
        var _this = this;
        this.updateValue = new EventEmitter();
        this.onDelete = new EventEmitter();
        this.buttonGroupStyle = common.buttonGroupStyleString;
        this.toggleOptional = function () {
            _this.value = common.toggleOptional(_this.value, _this.schema, _this.initialValue);
            _this.updateValue.emit({ value: _this.value, isValid: true });
        };
    }
    AnyEditorComponent.prototype.ngOnInit = function () {
        this.value = common.getDefaultValue(this.required, this.schema, this.initialValue);
        this.updateValue.emit({ value: this.value, isValid: true });
    };
    AnyEditorComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        if (this.monacoEditor && this.monacoEditorRef && this.monacoEditorRef.nativeElement) {
            this.monacoCodeEditor = this.monacoEditor.create(this.monacoEditorRef.nativeElement, {
                value: 'export default ' + JSON5.stringify(this.value, null, 2),
                language: 'javascript',
                minimap: { enabled: false },
                lineNumbers: 'off'
            });
            var timer_1;
            this.monacoCodeEditor.onDidChangeModelContent(function (e) {
                clearTimeout(timer_1);
                timer_1 = setTimeout(function () {
                    try {
                        var value = _this.monacoCodeEditor.getValue();
                        if (value.indexOf('export default') === 0) {
                            value = value.substring('export default'.length);
                        }
                        _this.value = JSON5.parse(value);
                        _this.updateValue.emit({ value: _this.value, isValid: true });
                    }
                    catch (error) {
                        // do nothing
                    }
                }, 500);
            });
        }
    };
    AnyEditorComponent.prototype.ngOnDestroy = function () {
        if (this.monacoCodeEditor) {
            this.monacoCodeEditor.dispose();
        }
    };
    Object.defineProperty(AnyEditorComponent.prototype, "titleToShow", {
        get: function () {
            return common.getTitle(this.title, this.schema.title);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AnyEditorComponent.prototype, "className", {
        get: function () {
            return this.schema.className ? this.theme.row + ' ' + this.schema.className : this.theme.row;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AnyEditorComponent.prototype, "isReadOnly", {
        get: function () {
            return this.readonly || this.schema.readonly;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AnyEditorComponent.prototype, "hasDeleteButtonFunction", {
        get: function () {
            return this.hasDeleteButton && !this.isReadOnly;
        },
        enumerable: true,
        configurable: true
    });
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Object)
    ], AnyEditorComponent.prototype, "schema", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", String)
    ], AnyEditorComponent.prototype, "initialValue", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", String)
    ], AnyEditorComponent.prototype, "title", void 0);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", Object)
    ], AnyEditorComponent.prototype, "updateValue", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Object)
    ], AnyEditorComponent.prototype, "theme", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Object)
    ], AnyEditorComponent.prototype, "icon", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Object)
    ], AnyEditorComponent.prototype, "locale", void 0);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", Object)
    ], AnyEditorComponent.prototype, "onDelete", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean)
    ], AnyEditorComponent.prototype, "readonly", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean)
    ], AnyEditorComponent.prototype, "required", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean)
    ], AnyEditorComponent.prototype, "hasDeleteButton", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Object)
    ], AnyEditorComponent.prototype, "monacoEditor", void 0);
    tslib_1.__decorate([
        ViewChild('monacoEditorRef', { static: false }),
        tslib_1.__metadata("design:type", ElementRef)
    ], AnyEditorComponent.prototype, "monacoEditorRef", void 0);
    AnyEditorComponent = tslib_1.__decorate([
        Component({
            selector: 'any-editor',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: anyEditorTemplateHtml
        })
    ], AnyEditorComponent);
    return AnyEditorComponent;
}());
export { AnyEditorComponent };
