import * as tslib_1 from "tslib";
import { Component, Input, Output, EventEmitter, ChangeDetectionStrategy, ViewChild, ElementRef } from '@angular/core';
import * as common from 'schema-based-json-editor';
import { stringEditorTemplateHtml } from './variables';
var StringEditorComponent = /** @class */ (function () {
    function StringEditorComponent() {
        var _this = this;
        this.updateValue = new EventEmitter();
        this.onDelete = new EventEmitter();
        this.buttonGroupStyle = common.buttonGroupStyleString;
        this.collapsed = false;
        this.trackByFunction = function (index) {
            return index;
        };
        this.toggleOptional = function () {
            _this.value = common.toggleOptional(_this.value, _this.schema, _this.initialValue);
            _this.validate();
            _this.updateValue.emit({ value: _this.value, isValid: !_this.errorMessage });
        };
        this.collapseOrExpand = function () {
            _this.collapsed = !_this.collapsed;
        };
    }
    StringEditorComponent.prototype.onChange = function (e) {
        this.value = e.target.value;
        this.validate();
        this.updateValue.emit({ value: this.value, isValid: !this.errorMessage });
    };
    StringEditorComponent.prototype.ngOnInit = function () {
        this.value = common.getDefaultValue(this.required, this.schema, this.initialValue);
        this.validate();
        this.updateValue.emit({ value: this.value, isValid: !this.errorMessage });
    };
    StringEditorComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        if (this.monacoEditor && this.monacoEditorRef && this.monacoEditorRef.nativeElement) {
            this.monacoCodeEditor = this.monacoEditor.create(this.monacoEditorRef.nativeElement, {
                value: this.value,
                language: 'json',
                minimap: { enabled: false },
                lineNumbers: 'off'
            });
            var timer_1;
            this.monacoCodeEditor.onDidChangeModelContent(function (e) {
                clearTimeout(timer_1);
                timer_1 = setTimeout(function () {
                    _this.value = _this.monacoCodeEditor.getValue();
                    _this.validate();
                    _this.validate();
                    _this.updateValue.emit({ value: _this.value, isValid: !_this.errorMessage });
                }, 500);
            });
        }
    };
    StringEditorComponent.prototype.ngOnDestroy = function () {
        if (this.monacoCodeEditor) {
            this.monacoCodeEditor.dispose();
        }
    };
    Object.defineProperty(StringEditorComponent.prototype, "useTextArea", {
        get: function () {
            return this.value !== undefined
                && (this.schema.enum === undefined || this.isReadOnly)
                && (this.schema.format === 'textarea' || this.schema.format === 'code' || this.schema.format === 'json' || this.schema.format === 'markdown');
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "useInput", {
        get: function () {
            return this.value !== undefined
                && !this.collapsed
                && (this.schema.enum === undefined || this.isReadOnly)
                && (this.schema.format !== 'textarea' && this.schema.format !== 'code' && this.schema.format !== 'json' && this.schema.format !== 'markdown');
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "useSelect", {
        get: function () {
            return this.value !== undefined && this.schema.enum !== undefined && !this.isReadOnly;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "useSelect2Component", {
        get: function () {
            return this.useSelect && !this.noSelect2 && this.schema.format !== 'select' && this.schema.format !== 'radiobox';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "useSelectComponent", {
        get: function () {
            return this.useSelect && (this.schema.format === 'select' || this.noSelect2);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "useRadioBoxComponent", {
        get: function () {
            return this.useSelect && this.schema.format === 'radiobox';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "canPreviewImage", {
        get: function () {
            return common.isImageUrl(this.value) || common.isBase64Image(this.value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "canPreviewMarkdown", {
        get: function () {
            return this.md && this.schema.format === 'markdown';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "canPreviewCode", {
        get: function () {
            return this.hljs && this.schema.format === 'code';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "canPreview", {
        get: function () {
            return (!!this.value) && (this.canPreviewImage || this.canPreviewMarkdown || this.canPreviewCode);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "getImageUrl", {
        get: function () {
            return this.forceHttps ? common.replaceProtocal(this.value) : this.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "getMarkdown", {
        get: function () {
            return this.md.render(this.value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "getCode", {
        get: function () {
            return this.hljs.highlightAuto(this.value).value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "isReadOnly", {
        get: function () {
            return this.readonly || this.schema.readonly;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "hasDeleteButtonFunction", {
        get: function () {
            return this.hasDeleteButton && !this.isReadOnly;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "willPreviewImage", {
        get: function () {
            return this.value && !this.collapsed && this.canPreviewImage;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "willPreviewMarkdown", {
        get: function () {
            return this.value && !this.collapsed && this.canPreviewMarkdown;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "willPreviewCode", {
        get: function () {
            return this.value && !this.collapsed && this.canPreviewCode;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "titleToShow", {
        get: function () {
            return common.getTitle(this.title, this.schema.title);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "options", {
        get: function () {
            return common.getOptions(this.schema);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "canUpload", {
        get: function () {
            return this.schema.format === 'base64';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringEditorComponent.prototype, "className", {
        get: function () {
            var rowClass = this.errorMessage ? this.theme.errorRow : this.theme.row;
            return this.schema.className ? rowClass + ' ' + this.schema.className : rowClass;
        },
        enumerable: true,
        configurable: true
    });
    StringEditorComponent.prototype.updateSelection = function (value) {
        this.value = value;
        this.validate();
        this.updateValue.emit({ value: this.value, isValid: !this.errorMessage });
    };
    StringEditorComponent.prototype.fileGot = function (file) {
        var _this = this;
        var reader = new FileReader();
        reader.readAsDataURL(file);
        reader.onload = function () {
            _this.value = reader.result;
            _this.validate();
            _this.updateValue.emit({ value: _this.value, isValid: !_this.errorMessage });
        };
        reader.onerror = function (error) {
            console.log(error);
        };
    };
    StringEditorComponent.prototype.validate = function () {
        this.errorMessage = common.getErrorMessageOfString(this.value, this.schema, this.locale);
    };
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Object)
    ], StringEditorComponent.prototype, "schema", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", String)
    ], StringEditorComponent.prototype, "initialValue", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", String)
    ], StringEditorComponent.prototype, "title", void 0);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", Object)
    ], StringEditorComponent.prototype, "updateValue", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Object)
    ], StringEditorComponent.prototype, "theme", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Object)
    ], StringEditorComponent.prototype, "icon", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Object)
    ], StringEditorComponent.prototype, "locale", void 0);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", Object)
    ], StringEditorComponent.prototype, "onDelete", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean)
    ], StringEditorComponent.prototype, "readonly", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean)
    ], StringEditorComponent.prototype, "required", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean)
    ], StringEditorComponent.prototype, "hasDeleteButton", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Function)
    ], StringEditorComponent.prototype, "dragula", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Object)
    ], StringEditorComponent.prototype, "md", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Object)
    ], StringEditorComponent.prototype, "hljs", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean)
    ], StringEditorComponent.prototype, "forceHttps", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean)
    ], StringEditorComponent.prototype, "noSelect2", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Object)
    ], StringEditorComponent.prototype, "monacoEditor", void 0);
    tslib_1.__decorate([
        ViewChild('monacoEditorRef', { static: false }),
        tslib_1.__metadata("design:type", ElementRef)
    ], StringEditorComponent.prototype, "monacoEditorRef", void 0);
    StringEditorComponent = tslib_1.__decorate([
        Component({
            selector: 'string-editor',
            styles: [
                ".schema-based-json-editor-image-preview {" + common.imagePreviewStyleString + "}"
            ],
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: stringEditorTemplateHtml
        })
    ], StringEditorComponent);
    return StringEditorComponent;
}());
export { StringEditorComponent };
